package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Aug 15, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
FromJSON converts a JSON-tagged value into a generic document for YAML.
type Encoder struct {
Indent int
}
Encoder marshals values to YAML using go.yaml.in/yaml/v4.
Marshal encodes v as YAML.
Write marshals v and writes it to w.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.